"use strict";
const RandomGenerator_1 = require("../util/RandomGenerator");
const StringUtils_1 = require("../util/StringUtils");
/**
 * Naming strategy that is used by default.
 */
class DefaultNamingStrategy {
    tableName(className, customName) {
        return customName ? customName : StringUtils_1.snakeCase(className);
    }
    columnName(propertyName, customName) {
        return customName ? customName : propertyName;
    }
    embeddedColumnName(embeddedPropertyName, columnPropertyName, columnCustomName) {
        return StringUtils_1.camelCase(embeddedPropertyName + "_" + (columnCustomName ? columnCustomName : columnPropertyName));
    }
    relationName(propertyName) {
        return propertyName;
    }
    indexName(customName, tableName, columns) {
        if (customName)
            return customName;
        const key = "ind_" + tableName + "_" + columns.join("_");
        return "ind_" + RandomGenerator_1.RandomGenerator.sha1(key).substr(0, 27);
    }
    joinColumnInverseSideName(joinColumnName, propertyName) {
        if (joinColumnName)
            return joinColumnName;
        return propertyName;
    }
    joinTableName(firstTableName, secondTableName, firstPropertyName, secondPropertyName, firstColumnName, secondColumnName) {
        return StringUtils_1.snakeCase(firstTableName + "_" + firstPropertyName + "_" + secondTableName + "_" + secondColumnName);
    }
    joinTableColumnName(tableName, columnName, secondTableName, secondColumnName) {
        const column1 = StringUtils_1.camelCase(tableName + "_" + columnName);
        const column2 = StringUtils_1.camelCase(secondTableName + "_" + secondColumnName);
        return column1 === column2 ? column1 + "_1" : column1; // todo: do we still need _1 prefix?!
    }
    joinTableInverseColumnName(tableName, columnName, secondTableName, secondColumnName) {
        const column1 = StringUtils_1.camelCase(tableName + "_" + columnName);
        const column2 = StringUtils_1.camelCase(secondTableName + "_" + secondColumnName);
        return column1 === column2 ? column1 + "_2" : column1; // todo: do we still need _2 prefix?!
    }
    closureJunctionTableName(tableName) {
        return tableName + "_closure";
    }
    foreignKeyName(tableName, columnNames, referencedTableName, referencedColumnNames) {
        const key = `${tableName}_${columnNames.join("_")}_${referencedTableName}_${referencedColumnNames.join("_")}`;
        return "fk_" + RandomGenerator_1.RandomGenerator.sha1(key).substr(0, 27); // todo: use crypto instead?
    }
    classTableInheritanceParentColumnName(parentTableName, parentTableIdPropertyName) {
        return StringUtils_1.camelCase(parentTableName + "_" + parentTableIdPropertyName);
    }
    /**
     * Adds prefix to the table.
     */
    prefixTableName(prefix, originalTableName) {
        return prefix + originalTableName;
    }
}
exports.DefaultNamingStrategy = DefaultNamingStrategy;

//# sourceMappingURL=DefaultNamingStrategy.js.map
